@@ -1,6 +1,5 @@
 #' @import cluster
 #' @importFrom utils combn
-#' @import clusterCrit
 #' @importFrom stats as.dist cutree hclust median
 #' @import Matrix
 
@@ -138,6 +137,30 @@ getnewk <- function(k, R, x, N) {
   return(newk1)
 }
 
+#' @importFrom stats cov
+calinhara <- function(x,clustering,cn=max(clustering)){
+  x <- as.matrix(x)
+  p <- ncol(x)
+  n <- nrow(x)
+  cln <- rep(0,cn)
+  W <- matrix(0,p,p)
+  for (i in 1:cn)
+    cln[i] <- sum(clustering==i)
+  #  print(cln)
+  for (i in 1:cn) {
+    clx <- x[clustering==i,]
+    cclx <- cov(as.matrix(clx))
+    #    print(cclx)
+    if (cln[i] < 2) 
+      cclx <- 0 
+    W <- W + ((cln[i] - 1) * cclx)
+  }
+  S <- (n - 1) * cov(x)
+  B <- S - W
+  out <- (n-cn)*sum(diag(B))/((cn-1)*sum(diag(W)))
+  out
+}
+
 get_opt_hclust <- function(mat, hmethod, N.cluster, minN.cluster, maxN.cluster, sil.thre,
                            height.Ntimes) {
   # if no agglomeration method for hierarchical clustering is provided
@@ -189,8 +212,9 @@ get_opt_hclust <- function(mat, hmethod, N.cluster, minN.cluster, maxN.cluster,
     f <- v  #the optimal clustering results
     sil <- silhouette(v, d)
     msil <- median(sil[, 3])
-    ch0 <- intCriteria(data.matrix(mat), as.integer(v), "Calinski_Harabasz")
-    CHind <- unlist(ch0, use.names = FALSE)  #convert a list to a vector/value
+    # ch0 <- intCriteria(data.matrix(mat), as.integer(v), "Calinski_Harabasz")
+    # CHind <- unlist(ch0, use.names = FALSE)  #convert a list to a vector/value
+    CHind <- calinhara(data.matrix(mat), as.integer(v))
     optN.cluster <- N.cluster
   }
   hres <- list()
